const StellarSDK = require("stellar-sdk");
const AccountCreateCollection = require("./../model/stellar/accountCreate");
require("dotenv").config();

async function GenerateKeyPairAndCreateAccount() {
  //get the server key pair
  const serverSourceKeyPair = StellarSDK.Keypair.fromSecret(
    process.env.STELLARSEED
  );
  const serverPubKey = serverSourceKeyPair.publicKey();
  const server = new StellarSDK.Server(process.env.STELLARTESTNET);

  //load server account
  const account = await server.loadAccount(serverPubKey);
  const fee = await server.fetchBaseFee();

  //generate random keypair
  const userKeyPair = StellarSDK.Keypair.random();

  //build the account funding transaction
  const accCreateTransaction = new StellarSDK.TransactionBuilder(account, {
    fee,
    networkPassphrase: StellarSDK.Networks.TESTNET,
  })
    .addMemo(StellarSDK.Memo.text("Create account"))
    .addOperation(
      StellarSDK.Operation.createAccount({
        destination: userKeyPair.publicKey(),
        startingBalance: "100",
      })
    )
    .setTimeout(30)
    .build();

  //sign the transaction
  accCreateTransaction.sign(serverSourceKeyPair);

  //send account creation transaction to BC
  try {
    const accCreateTxnResult = await server.submitTransaction(
      accCreateTransaction
    );
    console.log("New user account created: HASH : ", accCreateTxnResult.hash);
    console.log(
      "View account creation transaction 22222 at : https://horizon-testnet.stellar.org/transactions/" +
        accCreateTxnResult.hash
    );
    const timestamp = new Date();
    //create the account creation details collection object
    const createAccountObj = new AccountCreateCollection({
      publickey: userKeyPair.publicKey(),
      amount: "10XLM",
      timestamp: timestamp,
      transactionhash: accCreateTxnResult.hash,
    });

    //save the account creation details to the database
    const saveInCollection = await createAccountObj.save();
    console.log(
      "Account creation 22222 details saved in the database " + saveInCollection
    );

    return {
      publicKey: userKeyPair.publicKey(),
      privateKey: userKeyPair.secret(),
    };
  } catch (err) {
    console.log("Error submitting transaction:", err);
    throw err;
  }
}

module.exports = GenerateKeyPairAndCreateAccount;
