import React, { useState } from "react";
import { View, TextInput, TouchableOpacity, Text } from "react-native";
import { Ionicons } from "@expo/vector-icons";
import { useNavigation } from "@react-navigation/native";

export default function PatientMainChatView({ route }) {
  const [message, setMessage] = useState("");
  const [chatMessages, setChatMessages] = useState([]);
  const navigation = useNavigation();

  const sendMessage = () => {
    if (message.trim() === "") {
      return; // Don't send empty messages
    }

    const newMessage = {
      id: chatMessages.length + 1,
      text: message,
      sender: "Me",
      timestamp: new Date().toISOString(),
    };

    setChatMessages([...chatMessages, newMessage]);
    setMessage("");
  };

  const navigateToAllPractitioners = () => {
    // Navigate to the "All practitioners" view
    // Replace "AllPractitionersView" with the actual name of the view
    navigation.navigate("All Practitioners");
  };

  const navigateToNFTRequests = () => {
    // Navigate to the "NFT requests" view
    // Replace "NFTRequestsView" with the actual name of the view
    navigation.navigate("PatientNFTRequests");
  };

  const navigateToOthers = () => {
    // Navigate to the "Others" view
    // Replace "OthersView" with the actual name of the view
    navigation.navigate("OthersView");
  };

  return (
    <View style={{ flex: 1 }}>
      <View style={{ flexDirection: "row", alignItems: "center", padding: 10 }}>
        <Text style={{ fontSize: 20, marginLeft: 10 }}>Chat</Text>
      </View>
      {/* Chat messages */}
      <View style={{ flex: 1, padding: 10 }}>
        {chatMessages.map((msg) => (
          <View
            key={msg.id}
            style={{
              marginBottom: 10,
              alignSelf: msg.sender === "Me" ? "flex-end" : "flex-start",
            }}
          >
            <Text>{msg.text}</Text>
          </View>
        ))}
      </View>

      {/* Message input and send button */}
      <View style={{ flexDirection: "row", alignItems: "center", padding: 10 }}>
        <TextInput
          style={{
            flex: 1,
            borderWidth: 1,
            borderColor: "gray",
            borderRadius: 10,
            paddingHorizontal: 10,
          }}
          placeholder="Type your message..."
          value={message}
          onChangeText={(text) => setMessage(text)}
        />
        <TouchableOpacity onPress={sendMessage} style={{ marginLeft: 10 }}>
          <Ionicons name="send" size={24} color="blue" />
        </TouchableOpacity>
      </View>

      {/* Bottom buttons */}
      <View
        style={{
          flexDirection: "row",
          justifyContent: "space-around",
          backgroundColor: "lightgray",
          padding: 10,
        }}
      >
        <TouchableOpacity onPress={navigateToAllPractitioners}>
          <Text>All practitioners</Text>
        </TouchableOpacity>
        <TouchableOpacity onPress={navigateToNFTRequests}>
          <Text>NFT requests</Text>
        </TouchableOpacity>
        <TouchableOpacity onPress={navigateToOthers}>
          <Text>Others</Text>
        </TouchableOpacity>
      </View>
    </View>
  );
}
